@@ -24,7 +24,7 @@ def _saver(path, metadata, cdf_api_keys):
     """
     Upload model folder to CDF Files
     """
-    mm.setup(cdf_api_keys)
+    mm.setup(cdf_api_keys, c.dataset)
     model_info = mm.upload_new_model_version(
         c.model_name, 
         env,  
